summaryrefslogtreecommitdiff
path: root/libavcodec/libopenh264.c
diff options
context:
space:
mode:
Diffstat (limited to 'libavcodec/libopenh264.c')
-rw-r--r--libavcodec/libopenh264.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/libavcodec/libopenh264.c b/libavcodec/libopenh264.c
index 6252cfdc34..59c61a3a4c 100644
--- a/libavcodec/libopenh264.c
+++ b/libavcodec/libopenh264.c
@@ -2,20 +2,20 @@
* OpenH264 shared utils
* Copyright (C) 2014 Martin Storsjo
*
* This file is part of Libav.
*
* Libav is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2.1 of the License, or (at your option) any later version.
*
* Libav is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
- * License along with Libav; if not, write to the Free Software
+ * License along with FFmpeg; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/
@@ -27,8 +27,8 @@
#include "libopenh264.h"
-// Convert libopenh264 log level to equivalent libav log level.
-static int libopenh264_to_libav_log_level(int libopenh264_log_level)
+// Convert libopenh264 log level to equivalent ffmpeg log level.
+static int libopenh264_to_ffmpeg_log_level(int libopenh264_log_level)
{
if (libopenh264_log_level >= WELS_LOG_DETAIL) return AV_LOG_TRACE;
else if (libopenh264_log_level >= WELS_LOG_DEBUG) return AV_LOG_DEBUG;
@@ -40,10 +40,10 @@ static int libopenh264_to_libav_log_level(int libopenh264_log_level)
void ff_libopenh264_trace_callback(void *ctx, int level, const char *msg)
{
- // The message will be logged only if the requested EQUIVALENT libav log level is
- // less than or equal to the current libav log level.
- int equiv_libav_log_level = libopenh264_to_libav_log_level(level);
- av_log(ctx, equiv_libav_log_level, "%s\n", msg);
+ // The message will be logged only if the requested EQUIVALENT ffmpeg log level is
+ // less than or equal to the current ffmpeg log level.
+ int equiv_ffmpeg_log_level = libopenh264_to_ffmpeg_log_level(level);
+ av_log(ctx, equiv_ffmpeg_log_level, "%s\n", msg);
}
int ff_libopenh264_check_version(void *logctx)
@@ -2,20 +2,20 @@
* Copyright (C) 2014 Martin Storsjo
*
- * This file is part of Libav.
+ * This file is part of FFmpeg.
*
@@ -2,20 +2,20 @@
*
- * Libav is free software; you can redistribute it and/or
+ * FFmpeg is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
@@ -2,20 +2,20 @@
* version 2.1 of the License, or (at your option) any later version.
*
- * Libav is distributed in the hope that it will be useful,
+ * FFmpeg is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU